==> jc-1.4.0.tar.gz: javax/swing/JPasswordField__24AccessibleJPasswordField.h <==
// public class javax.swing.JPasswordField$AccessibleJPasswordField

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 5ad51d714721b807 javax_swing_JPasswordField__24AccessibleJPasswordField
// @dep_class 73be17e96ed15ae2 javax_swing_JTextField__24AccessibleJTextField
// @dep_class c8d812b116a1948e javax_swing_text_JTextComponent__24AccessibleJTextComponent

// header file dependencies
// @dep_header javax_swing_JTextField__24AccessibleJTextField

#include "javax/swing/JTextField__24AccessibleJTextField.h"

#ifndef _JC_javax_swing_JPasswordField__24AccessibleJPasswordField_H_
#define _JC_javax_swing_JPasswordField__24AccessibleJPasswordField_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_JPasswordField$object;

// Typedefs
typedef struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$sub_refs	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$sub_refs;
typedef struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$sub_nonrefs	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$sub_nonrefs;
typedef struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$refs	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$refs;
typedef struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$nonrefs	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$nonrefs;
typedef struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$object	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$object;

typedef struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$fields_struct	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$fields_struct;
typedef const struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vmethods	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vmethods;
typedef const struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtable	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtable;
typedef const struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtype	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtype;

// Class fields structure
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$fields_struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$class_fields;

// Constructors
extern void _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$method$_init$39e8988b24577765(_jc_env *, struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$object *, struct _jc_javax_swing_JPasswordField$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$object *);
};

// Vtable
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_text_JTextComponent__24AccessibleJTextComponent$vmethods	javax_swing_text_JTextComponent__24AccessibleJTextComponent;
	_jc_javax_swing_JTextField__24AccessibleJTextField$vmethods	javax_swing_JTextField__24AccessibleJTextField;
	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vmethods	javax_swing_JPasswordField__24AccessibleJPasswordField;
};

// Vtype
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtype {
	_jc_type			type;
	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$sub_refs {
	struct _jc_javax_swing_JPasswordField$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$refs {
    _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$sub_refs	javax_swing_JPasswordField__24AccessibleJPasswordField;
    _jc_javax_swing_JTextField__24AccessibleJTextField$sub_refs	javax_swing_JTextField__24AccessibleJTextField;
    _jc_javax_swing_text_JTextComponent__24AccessibleJTextComponent$sub_refs	javax_swing_text_JTextComponent__24AccessibleJTextComponent;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_text_JTextComponent__24AccessibleJTextComponent$sub_nonrefs	javax_swing_text_JTextComponent__24AccessibleJTextComponent;
    _jc_javax_swing_JTextField__24AccessibleJTextField$sub_nonrefs	javax_swing_JTextField__24AccessibleJTextField;
    _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$sub_nonrefs	javax_swing_JPasswordField__24AccessibleJPasswordField;
};

// Object instance structure
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$object {
	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtype	*vtype;
	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtype _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JPasswordField__24AccessibleJPasswordField, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$class_object;

#endif	/* _JC_javax_swing_JPasswordField__24AccessibleJPasswordField_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JPasswordField__24AccessibleJPasswordField.h <==
// public class javax.swing.JPasswordField$AccessibleJPasswordField

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class 5ad51d714721b807 javax_swing_JPasswordField__24AccessibleJPasswordField
// @dep_class 73be17e96ed15ae2 javax_swing_JTextField__24AccessibleJTextField
// @dep_class c8d812b116a1948e javax_swing_text_JTextComponent__24AccessibleJTextComponent

// header file dependencies
// @dep_header javax_swing_JTextField__24AccessibleJTextField

#include "javax/swing/JTextField__24AccessibleJTextField.h"

#ifndef _JC_javax_swing_JPasswordField__24AccessibleJPasswordField_H_
#define _JC_javax_swing_JPasswordField__24AccessibleJPasswordField_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_swing_JPasswordField$object;

// Typedefs
typedef struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$sub_refs	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$sub_refs;
typedef struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$sub_nonrefs	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$sub_nonrefs;
typedef struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$refs	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$refs;
typedef struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$nonrefs	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$nonrefs;
typedef struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$object	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$object;

typedef struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$fields_struct	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$fields_struct;
typedef const struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vmethods	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vmethods;
typedef const struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtable	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtable;
typedef const struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtype	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtype;

// Class fields structure
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$fields_struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$class_fields;

// Constructors
extern void _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$method$_init$39e8988b24577765(_jc_env *, struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$object *, struct _jc_javax_swing_JPasswordField$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$method_info$getAccessibleRole$eaa05a502d0ede18;

// Virtual methods structure
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_text_JTextComponent__24AccessibleJTextComponent$vmethods	javax_swing_text_JTextComponent__24AccessibleJTextComponent;
	_jc_javax_swing_JTextField__24AccessibleJTextField$vmethods	javax_swing_JTextField__24AccessibleJTextField;
	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vmethods	javax_swing_JPasswordField__24AccessibleJPasswordField;
};

// Vtype
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtype {
	_jc_type			type;
	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$sub_refs {
	struct _jc_javax_swing_JPasswordField$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$refs {
    _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$sub_refs	javax_swing_JPasswordField__24AccessibleJPasswordField;
    _jc_javax_swing_JTextField__24AccessibleJTextField$sub_refs	javax_swing_JTextField__24AccessibleJTextField;
    _jc_javax_swing_text_JTextComponent__24AccessibleJTextComponent$sub_refs	javax_swing_text_JTextComponent__24AccessibleJTextComponent;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_text_JTextComponent__24AccessibleJTextComponent$sub_nonrefs	javax_swing_text_JTextComponent__24AccessibleJTextComponent;
    _jc_javax_swing_JTextField__24AccessibleJTextField$sub_nonrefs	javax_swing_JTextField__24AccessibleJTextField;
    _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$sub_nonrefs	javax_swing_JPasswordField__24AccessibleJPasswordField;
};

// Object instance structure
struct _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$object {
	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtype	*vtype;
	_jc_javax_swing_JPasswordField__24AccessibleJPasswordField$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$vtype _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JPasswordField__24AccessibleJPasswordField, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JPasswordField__24AccessibleJPasswordField$class_object;

#endif	/* _JC_javax_swing_JPasswordField__24AccessibleJPasswordField_H_ */
